@@ -533,7 +533,7 @@ namespace shevek
 			s = a.substr (0, precision);
 		else
 			s = a;
-		if (width >= 0 && s.size () < width)
+		if (s.size () < width)
 		{
 			if (flags.find ('-'))
 				s += Glib::ustring (width - s.size (), ' ');
